summaryrefslogtreecommitdiff
path: root/Source/DecodePic.S
diff options
context:
space:
mode:
authorChristian A. Weber <chris@gna.ch>1992-05-15 03:21:10 +0000
committerChristian A. Weber <chris@gna.ch>1992-05-15 03:21:10 +0000
commite556b972d1ad64453b3372b486191e2a59c91dda (patch)
tree4eb9264758c36cc75cdcf8daf8dde1517d77cb6a /Source/DecodePic.S
parent36c824864c02f0a3f62c8a1d365d1670835c8c96 (diff)
downloadiff-library-e556b972d1ad64453b3372b486191e2a59c91dda.tar.gz
iff-library-e556b972d1ad64453b3372b486191e2a59c91dda.tar.bz2
iff-library-e556b972d1ad64453b3372b486191e2a59c91dda.zip
An neue Include-Files angepasst
Diffstat (limited to 'Source/DecodePic.S')
-rw-r--r--Source/DecodePic.S50
1 files changed, 25 insertions, 25 deletions
diff --git a/Source/DecodePic.S b/Source/DecodePic.S
index e8877a5..b1f3136 100644
--- a/Source/DecodePic.S
+++ b/Source/DecodePic.S
@@ -1,13 +1,13 @@
**
-** $Id: $
-** $Revision: $
+** $Id: DecodePic.S,v 1.1 92/05/12 22:26:36 chris Exp $
+** $Revision: 1.1 $
**
** $Filename: DecodePic.S $
-** $Author: Christian A. Weber $
+** $Author: chris $
** $Release: 19.1 $
-** $Date: 92/05/11 21:11:27 $
+** $Date: 92/05/12 22:26:36 $
**
-** iff.library/IFFLib_DecodePic
+** iff.library/IFFL_DecodePic
**
** COPYRIGHT (C) 1987-1992 BY CHRISTIAN A. WEBER, BRUGGERWEG 2,
** CH-8037 ZUERICH, SWITZERLAND. ALL RIGHTS RESERVED. NO PART
@@ -17,7 +17,7 @@
**
- IDNT IFFLib_DecodePic
+ IDNT IFFL_DecodePic
SECTION text,CODE
INCLUDE "IFFLib.i"
@@ -26,16 +26,16 @@
XDEF DecodePicFunc
-******* iff.library/IFFLib_DecodePic ****************************************
+******* iff.library/IFFL_DecodePic ******************************************
*
* NAME
* IFFLib_DecodePic -- decode the BODY of an ILBM file into a BitMap
*
* SYNOPSIS
-* success = IFFLib_DecodePic( ifffile, bitmap )
-* D0 A1 A0
+* success = IFFL_DecodePic( iff, bitmap )
+* D0 A1 A0
*
* BOOL IFFLib_DecodePic( IFFFILE, struct BitMap * )
*
* FUNCTION
* Decodes and decompresses a picture into the user supplied BitMap.
@@ -44,23 +44,23 @@
* will be drawn into the top left corner of your BitMap.
* If the picture has less planes than the BitMap, the unused planes
* are NOT touched by this routine, so you may wish to clear them
* before calling IFFLib_DecodePic(). If the picture has more planes
* than your BitMap, the surplus planes of the picture are ignored.
*
* INPUTS
* ifffile - IFF file pointer, from IFFLib_OpenIFF()
* bitmap - Pointer to a properly initialized BitMap structure:
* bm_Planes[] must point to valid BitPlanes,
* bm_Depth contains the number of planes.
* bm_Width and bm_Height must be set according to the
* size of your bit planes.
*
* RESULTS
* Non-zero if OK, 0 if error, Call IFFError() to know the reason
* of the failure
*
* NOTE
-* This routine needs at least 620 bytes of stack space
+* This routine needs at least 650 bytes of stack space
*
* SEE ALSO
*
@@ -81,7 +81,7 @@ DecodePicFunc: movem.l d2-d7/a2-a6,-(SP)
cmpi.l #'ILBM',8(a4) ; ist's überhaupt ein ILBM-File ?
beq.s 1$ ; ja --->
- moveq #IFF_NOILBM,d0 ; Fehlernummer
+ moveq #IFFL_ERROR_NOILBM,d0 ; Fehlernummer
bra .Error
1$:
*** BitMapHeader suchen und nach A2
@@ -89,7 +89,7 @@ DecodePicFunc: movem.l d2-d7/a2-a6,-(SP)
bsr GetBMHDFunc ; BitMapHeader suchen
;; tst.l d0
bne.s 2$ ; gefunden --->
- moveq #IFF_NOBMHD,d0 ; Fehlernummer
+ moveq #IFFL_ERROR_NOBMHD,d0 ; Fehlernummer
bra .Error
2$: movea.l d0,a2 ; A2: BitMapHeader
@@ -113,7 +113,7 @@ DecodePicFunc: movem.l d2-d7/a2-a6,-(SP)
bsr FindChunkFunc
;; tst.l d0
bne.s 4$ ; gefunden --->
- moveq #IFF_NOBODY,d0 ; Fehlernummer
+ moveq #IFFL_ERROR_NOBODY,d0 ; Fehlernummer
bra .Error
4$:
movea.l d0,a0 ; A0 : Body-Adresse
@@ -133,7 +133,7 @@ DecodePicFunc: movem.l d2-d7/a2-a6,-(SP)
lea DecrunchRow(PC),a6 ; CmpByteRun1
bra.s 7$ ; --->
6$:
- moveq #IFF_UNKNOWNCOMPRESSION,d0
+ moveq #IFFL_ERROR_BADCOMPRESSION,d0
bra.s .Error
7$:
*** Masking testen und wenn 'hasmask' (Stencil) D7.B:=$FF, sonst $00
@@ -26,16 +26,16 @@
*
* NAME
-* IFFLib_DecodePic -- decode the BODY of an ILBM file into a BitMap
+* IFFL_DecodePic -- decode the BODY of an ILBM file into a BitMap
*
* SYNOPSIS
@@ -26,16 +26,16 @@
*
-* BOOL IFFLib_DecodePic( IFFFILE, struct BitMap * )
+* BOOL IFFL_DecodePic( IFFL_HANDLE, struct BitMap * )
*
* FUNCTION
@@ -44,23 +44,23 @@
* If the picture has less planes than the BitMap, the unused planes
* are NOT touched by this routine, so you may wish to clear them
-* before calling IFFLib_DecodePic(). If the picture has more planes
+* before calling IFFL_DecodePic(). If the picture has more planes
* than your BitMap, the surplus planes of the picture are ignored.
*
@@ -44,23 +44,23 @@
*
* INPUTS
-* ifffile - IFF file pointer, from IFFLib_OpenIFF()
-* bitmap - Pointer to a properly initialized BitMap structure:
-* bm_Planes[] must point to valid BitPlanes,
-* bm_Depth contains the number of planes.
-* bm_Width and bm_Height must be set according to the
-* size of your bit planes.
+* iff - IFF file handle, from IFFL_OpenIFF()
+* bitmap - Pointer to a properly initialized BitMap structure:
+* bm_Planes[] must point to valid BitPlanes,
+* bm_Depth contains the number of planes.
+* bm_Width and bm_Height must be set according to the
+* size of your bit planes.
*
* RESULTS
@@ -44,23 +44,23 @@
*
* RESULTS
-* Non-zero if OK, 0 if error, Call IFFError() to know the reason
-* of the failure
+* Non-zero if successful, zero if error. Call IFFL_IFFError() to
+* know the reason of the failure
*
* NOTE